==> ScreenPinKit-1.0-py3-none-any.whl: common/template_config.py <==
TEMPLATE_CONFIG = '''
{
    "ArrowToolbar": {
        "brushColor": "#ffff0000",
        "penColor": "#ffff0000",
        "penStyle": 1,
        "penWidth": 2
    },
    "General": {
        "CacheFolder": "./cache",
        "DpiScale": "Auto",
        "ImageNameFormat": "ScreenPinKit_%s.png",
        "Language": "Auto"
    },
    "Update": {
        "CheckUpdateAtStartUp": true
    },
    "EffectToolbar": {
        "effectType": "Blur",
        "strength": 5
    },
    "EraseToolbar": {
        "width": 5
    },
    "LineStripToolbar": {
        "penColor": "#ffff0000",
        "penWidth": 5
    },
    "MarkerPenToolbar": {
        "penColor": "#995f0f26",
        "penWidth": 16
    },
    "HotKey": {
        "MouseThough": "alt+f",
        "ScreenPaint": "f4",
        "ScreenShot": "f7",
        "ShowClipboard": "f2",
        "SwitchScreenPaintMode": "alt+l"
    },
    "NumberMarkerItemToolbar": {
        "penColor": "#ffff0000",
        "penStyle": 1,
        "penWidth": 2,
        "fontFamily": "Microsoft YaHei",
        "textColor": "#ffffffff"
    },
    "PenToolbar": {
        "penColor": "#ffff0000",
        "penWidth": 5
    },
    "ShapeToolbar": {
        "brushColor": "#00ff00ff",
        "penColor": "#ffff0000",
        "penStyle": 1,
        "penWidth": 2,
        "shape": "Rectangle"
    },
    "TextEditToolbar": {
        "fontFamily": "Microsoft YaHei",
        "fontSize": 15,
        "textColor": "#ffff007f"
    },
    "QFluentWidgets": {
        "ThemeColor": "#ff009faa",
        "ThemeMode": "Auto"
    },
    "Toolbar": {
        "applyWheelItem": true,
        "useWheelZoom": true
    },
    "WindowShadowStyle": {
        "focusColor": "#00ff00ff",
        "isCopyWithShadow": false,
        "isSaveWithShadow": false,
        "unFocusColor": "#007d7d7d",
        "useRoundStyle": true
    }
}'''

==> ScreenPinKit-1.1-py3-none-any.whl: common/template_config.py <==
TEMPLATE_CONFIG = '''
{
    "ArrowToolbar": {
        "brushColor": "#ffff0000",
        "penColor": "#ffff0000",
        "penStyle": 1,
        "penWidth": 2
    },
    "General": {
        "CacheFolder": "./cache",
        "DpiScale": "Auto",
        "ImageNameFormat": "ScreenPinKit_%s.png",
        "Language": "Auto"
    },
    "Update": {
        "CheckUpdateAtStartUp": true
    },
    "EffectToolbar": {
        "effectType": "Blur",
        "strength": 5
    },
    "EraseToolbar": {
        "width": 5
    },
    "LineStripToolbar": {
        "penColor": "#ffff0000",
        "penWidth": 5
    },
    "MarkerPenToolbar": {
        "penColor": "#995f0f26",
        "penWidth": 16
    },
    "HotKey": {
        "MouseThough": "alt+f",
        "ScreenPaint": "f4",
        "ScreenShot": "f7",
        "ShowClipboard": "f2",
        "SwitchScreenPaintMode": "alt+l"
    },
    "NumberMarkerItemToolbar": {
        "penColor": "#ffff0000",
        "penStyle": 1,
        "penWidth": 2,
        "fontFamily": "Microsoft YaHei",
        "textColor": "#ffffffff",
        "brushColor": "#7fff0000"
    },
    "PenToolbar": {
        "penColor": "#ffff0000",
        "penWidth": 5
    },
    "ShapeToolbar": {
        "brushColor": "#00ff00ff",
        "penColor": "#ffff0000",
        "penStyle": 1,
        "penWidth": 2,
        "shape": "Rectangle"
    },
    "TextEditToolbar": {
        "fontFamily": "Microsoft YaHei",
        "fontSize": 15,
        "textColor": "#ffff007f"
    },
    "QFluentWidgets": {
        "ThemeColor": "#ff009faa",
        "ThemeMode": "Auto"
    },
    "Toolbar": {
        "applyWheelItem": true,
        "useWheelZoom": true
    },
    "WindowShadowStyle": {
        "focusColor": "#00ff00ff",
        "isCopyWithShadow": false,
        "isSaveWithShadow": false,
        "unFocusColor": "#007d7d7d",
        "useRoundStyle": true
    }
}'''
